import { IF010016 } from "./services/IF010016";
type ResolveType<T> = T extends Promise<infer R> ? R : never;
type IIF010016Resolve = ResolveType<ReturnType<typeof IF010016>>;
export type AccountsType = IIF010016Resolve["accounts"][number];
export interface ITwiceLoginParams {
    /**
     * 没有资金账户回调
     */
    doWhenWithoutAccount?: () => boolean;
    /**
     * 提交/续签成功回调
     */
    success?: (arg?: AccountsType) => void;
    /**
     * 提交/续签失败回调
     */
    failure?: (arg?: any) => void;
    /**
     * 取消
     */
    cancel?: (arg?: any) => void;
    /**
     * 取消后是否强制退出，默认为true，即取消后不会强制退出
     */
    cancelIsForceQuit?: boolean;
}
/**
 * 键盘确认后传参数类型
 */
export interface ISubmit {
    /**
     * 混淆密码
     */
    password: string;
}
/**
 * 短登录请求参数
 */
export declare class ShortLoginRequest {
    /**
     * 需要做二级登录的资金账户（当不使用该字段时，默认以当前原生端登录的账号作为二级登录账号）
     */
    fundAccount?: string;
    /**
     * 所需要登录的账户系统，可用于限制特定账号的登录权限
     */
    fundType?: BizSysId[];
    /**
     * 是否带用户交互界面（该属性目前仅支持app端）
     * 如果设置为false，则二级登录不会弹出用户操作交互界面，即不会弹出短登录原生面板
     */
    isInteractive?: boolean;
}
/**
 * 账户系统编号
 */
export declare enum BizSysId {
    /**
     * 集中交易
     */
    trade = "3",
    /**
     * 融资融券
     */
    rong = "6",
    /**
     * 期权
     */
    option = "18",
    /**
     * 养老金
     */
    pension = "810"
}
/**
 * 短登录返回参数类型
 */
export interface ShortLoginResponse {
    /**
     * 是否登录（true-已登录；false-未登录）
     */
    isLogin: boolean;
    /**
     * 客户名称
     */
    clientName?: string;
    /**
     * 二级登录验证通过后的资金账户，一般为输入参数中的资金账户
     */
    fundAccount?: string;
    /**
     * 当前登录成功后的账户类型
     */
    bizSysId?: BizSysId;
}
export {};
